import argparse

from pyjuzi.room import RoomApi


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--endpoint",
                        dest="endpoint",
                        default="ex-api.botorange.com",
                        type=str,
                        help="api endpoint")
    parser.add_argument(
        "--token", dest="token", required=True, help="api token")
    args = parser.parse_args()
    room_api = RoomApi(args.endpoint, args.token)
    print(room_api.list_rooms(0, 10))



from .transport import Transport


class RoomApi(object):

    def __init__(self, endpoint: str, token: str):
        self.transport = Transport(endpoint=endpoint, token=token)

    def list_rooms(self, page_num: int, page_size: int, wxid: str = ""):
        param = {
            "current": page_num,
            "pageSize": page_size
        }
        if wxid:
            param["wxid"] = wxid
        return self.transport.get("/room/list", param)



class ApiException(Exception):

    def __init__(self, code: int, message: str):
        self.code = code
        self.message = message

    def __str__(self):
        return f"{self.code}:{self.message}"



import http.client
import json
import urllib.parse

from .exception import ApiException


def get_error_message(message: str):
    message = json.loads(message)
    return message.get("message", "")


class Transport(object):

    def __init__(self, endpoint: str, token: str):
        self.token = token
        self.endpoint = endpoint
        self.connection = http.client.HTTPSConnection(self.endpoint)

    def get(self, path: str, param: dict):
        param["token"] = self.token
        query = urllib.parse.urlencode(param)
        print(f"{path}?{query}")
        self.connection.request("GET", f"{path}?{query}")
        response = self.connection.getresponse()
        if response.code < 400:
            return json.loads(response.read())
        else:
            message = get_error_message(response.read())
            raise ApiException(response.code, message)

    def post(self, path: str, param: dict):
        headers = {'Content-type': 'application/json'}
        body = json.dumps(param)
        self.connection.request("POST", path, body, headers)
        response = self.connection.getresponse()
        if response.code < 400:
            return json.loads(response.read())
        else:
            message = get_error_message(response.read())
            raise ApiException(response.code, message)



import argparse

from pyjuzi.contact import ContactApi


if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("--endpoint",
                        dest="endpoint",
                        default="ex-api.botorange.com",
                        type=str,
                        help="api endpoint")
    parser.add_argument(
        "--token", dest="token", required=True, help="api token")
    args = parser.parse_args()
    contact_api = ContactApi(args.endpoint, args.token)
    print(contact_api.list_contact(0, 10))



from setuptools import find_packages, setup
from pyjuzi import __version__

setup(
    name='pyjuzi',
    version=__version__,
    license='PRIVATE',
    author='fatelei',
    author_email='fatelei@gmail.com',
    url='https://github.com/fatelei/pyjuzi',
    description='juzi python sdk',
    packages=find_packages(where='.', exclude=['tests', 'scripts']),
    zip_safe=False,
)
